<?php
/**
 * @Copyright
 *
 * @package js_weather class *
 * @author     Joachim Schmidt {@link http://www.jschmidt-systemberatung.de/}
 * @version Version: 1.0.0 - March 2023
 * @desciption Application to provide weather forcast weather data ftom openWeatherMap
 * @link       Project Site {@link http://www.jschmidt-systemberatung.de/}
 *
 * @license GNU/GPL
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * change activity:
 */

 defined ( '_JEXEC' ) or die ( 'Restricted access' );
 include_once (dirname(__FILE__) . '/settings.php');
 ?>
 
<link href="<?php echo $app_root; ?>/jsweather/css/weather.css" rel="stylesheet" />
<script type="text/javascript" src="<?php echo $app_root; ?>/jsweather/phpRGraph/libraries/RGraph.common.lib.js"></script>

<?php
use jsweather\js_weather;
include_once (dirname(__DIR__) . '/js_weather.php');

if (array_key_exists('lang', $_GET))
    $lang = htmlspecialchars($_GET['lang']);

$text = parse_ini_file(dirname(__DIR__) . "/weather.ini", true);
$valid_languages = $text['languages'];
if (strpos($valid_languages, $lang) === false)
    $lang = "en";
$text = $text[$lang];

if (array_key_exists('location', $_GET))
{
     $location = strip_tags($_GET['location']);
     $location = htmlspecialchars($location);
}
    
if (array_key_exists('use_ip', $_GET))
    $use_ip = htmlspecialchars($_GET['use_ip']);

if (array_key_exists('cache', $_GET))
    $cachetime = htmlspecialchars($_GET['cache']);

$dir = JPATH_BASE . "/cache/js_weather";
if ($cachetime > 0)
{
    if (! file_exists($dir))
        mkdir(JPATH_BASE . '/cache/js_weather', 0755);
}
$file = $dir . "/save_weatherdata." . $lang;

if (file_exists($file) && $cachetime > 0)
    $changedTime = filemtime($file);
else
    $changedTime = time();

$currentTime = time();

$myweather = new js_weather($key, true);
$myweather->setLanguage($lang);
$myweather->setID($lang);
//$myweather->beautify_json = true;

$rc = $myweather->setLocation($location, $use_ip);
if ($rc == false)
{
    printf ( $text['location_error'], $location);
    return;
}

if ($myweather->getUseIP() == true)
   $cachetime = 0;

if ($cachetime > 0)
{
    if (! file_exists($file) || ($currentTime - $changedTime) > $cachetime)
    {
        $weather_info = json_decode($myweather->get_weather_data($dir));
          
        if ($weather_info->cod != 200)
        {
           echo $text['error'] . errorMsg($weather_info->cod, $text, $weather_info->message);
           return;
        }
        else
            $changedTime = time();
    }
    else
    {
        $fp = fopen($file, "r");
        $data = fread($fp, filesize($file));
        $weather_info = json_decode($data);
        $changedTime = filemtime($file);
    }
}
else
{
    $weather_info = json_decode($myweather->get_weather_data());
    $changedTime = time();
        
    if ($weather_info->cod != 200)
    {
        echo $text['error'] .  errorMsg($weather_info->cod, $text, $weather_info->message);
        return;
    }
}

//echo chartScript ($lang, $RGraph_Url, $weather_info);
$date = setmyDate($lang, $text, $changedTime);

?>

<div class='my_weather-container'>
<div style="text-align: center; margin-bottom: -20px; margin-top: -20px">
<h3 style='font-size: 1.15em;'><?php echo  $text['title'] . $weather_info->city->name . " (" . $weather_info->city->country; ?>)</h3>
  <?php echo $text['data'] .  $date . " - " . date($text['timeform'], $changedTime) . $text['hour']; ?>
</div>
<div style='overflow-x:auto;'>
<p>&nbsp;</p><table class='my_weather-table'><tr>

<?php

$j = 0;
if ($lang == "en")
    $form = "n-j-Y";
 else
    $form = "j.n.Y";
 
$background = 'background-image: url(' . $app_root . '/jsweather/images/bright.png);background-size: cover;background-repeat: no-repeat, repeat;';

for ($i = 0; $i < count($weather_info->list); $i ++)
{
    if (strpos($weather_info->list[$i]->dt_txt, "9:00"))
    {
        $key = date($form, $weather_info->list[$i]->dt);
        $data1[$key] = round($weather_info->list[$i]->main->temp, 0);
    }
    
    if (strpos($weather_info->list[$i]->dt_txt, "15:00"))
    {
        $key = date($form, $weather_info->list[$i]->dt);
        $data2[$key] = round($weather_info->list[$i]->main->temp, 0);
    }
    
    if (strpos($weather_info->list[$i]->dt_txt, "12:00"))
    {
        $wind_dir = getWindDirection($text, $weather_info->list[$i]->wind->deg);
        if ($weather_info->list[$i]->wind->speed > 50)
           $color = " style='color: red;'";
        else
           $color = '';
        $j++;
        if ($j > 4)
        {
            echo "</td></tr></table><table class='my_weather-table'><tr>";
        }
        echo "<td style='" . $background . " width: 160px;text-align: center;'><h4 style='font-size: 1.0em;'>" . setmyDate($lang, $text,  $weather_info->list[$i]->dt) . "</h4>";
?>
  <div class="my_weather-info">
   <b><?php echo ucwords($weather_info->list[$i]->weather[0]->description); ?></b>
  </div>
  <div class="my_weather-temperature">
    <img class="my_weather-icon" src="https://openweathermap.org/img/w/<?php echo $weather_info->list[$i]->weather[0]->icon; ?>.png">
     <?php  echo round($weather_info->list[$i]->main->temp,0);?>°C
  </div>
   <p>&nbsp;</p>
  <div class="my_weather-misc">
   <div> <?php echo $text['pop'] . $myweather->format_number($weather_info->list[$i]->pop * 100, 0); ?>%</div>
   <div<?php echo $color; ?>> <?php echo $text['wind'] .  $myweather->format_number($weather_info->list[$i]->wind->speed, 1); ?> km/h <?php echo $wind_dir;?></div>
   <div> <?php echo $text['visibility'] . $myweather->format_number($weather_info->list[$i]->visibility,0); ?> m</div>
   <div> <?php echo $text['pressure'] . $myweather->format_number($weather_info->list[$i]->main->pressure,0); ?> hPa</div>
   </div>
  <br>
</td>
<?php
   }
}
?>
<td><div id='show-sample'></div></td>
</tr></table></div></div>

<?php
echo chartScript ($lang, $RGraph_Url, $data1, $data2);
function errorMsg ($code, $text, $msg)
{
    switch ($code)
    {
        case 400:
            return "(400) " . $text['400'] . ", <b>Response:</b> " . $msg;
            break;
        case 401:
            return "(401) " . $text['401'];
            break;
        case 404:
            return "(404) " . $text['404'];
            break;
        case 429:
            return "(429) " . $text['429'];
            break;
        default:
            if ($code == null)
              return "(nav) " . $text['nav'];
            else
              return "(" . $code . ") " . $msg;
    }
}

function getWindDirection($text, $deg)
{
    $winddir = [ $text["wind_N"],
                 $text["wind_NE"], $text["wind_E"], $text["wind_SE"], $text["wind_S"],
                 $text["wind_SW"], $text["wind_W"], $text["wind_NW"], $text["wind_N"] ];
    
    return $winddir[round($deg*8/360)];
}

function setmyDate($lang, $text,  $time)
{
    if ($lang =='en')
       $date =  date("jS F, Y", $time);
    else
       $date = date("j. ",$time) . $text['month'][date("n", $time)] . date( " Y", $time);

    return $date;
}

function chartScript ($lang, $url, $data1, $data2)
{
    $labels = array();
    $data9 = array();
    $data15 = array();

    foreach ($data1 as $key => $value)
    {
        if (array_key_exists($key, $data2))
        {
            array_push($labels, $key);
            array_push($data9, $value);
            array_push($data15, $data2[$key]);
        }
    }

    $data = [ 'labels' => $labels,
               'data' => [ $data9, $data15 ] ];
    $data = json_encode($data);

    $script = "
      <script type='text/javascript'>
        jQuery(document).ready(function() {
         var data = JSON.stringify(" . $data . ");
         var url = '" . $url . "?lang=" . $lang . "&data=' +data;
         jQuery('#show-sample' ).load( url, function() {
       });
     });
     </script> ";

    return $script;
}

?>

